"use client";

import React, { useEffect, useState, Suspense } from 'react';
import { useSearchParams } from 'next/navigation';
import CastBasicInfo from '../components/CastBasicInfo';
import CastMovies from '../components/CastMovies';
import Head from 'next/head'; // Import Head for SEO
import AdSense from '@/app/components/AdSense';

const CastPage: React.FC = () => {
  const searchParams = useSearchParams();
  const id = searchParams.get('id') || '';  // Ensure id is a string, fallback to an empty string
  const [castData, setCastData] = useState<any>(null);
  const [loading, setLoading] = useState(true);

  useEffect(() => {
    if (id) {
      const fetchCastData = async () => {
        try {
          const response = await fetch(
            `https://api.themoviedb.org/3/person/${id}?api_key=${process.env.NEXT_PUBLIC_TMDB_API_KEY}`
          );
          const data = await response.json();
          setCastData(data);
        } catch (error) {
          console.error('Failed to fetch cast data:', error);
        } finally {
          setLoading(false);
        }
      };

      fetchCastData();
    }
  }, [id]);

  if (loading) {
    return (
      <div className="flex flex-col items-center justify-center h-screen">
        <div className="animate-shake text-6xl">
          <span role="img" aria-label="smiling emoji">
            😊
          </span>
        </div>
        <div className="mt-4 text-xl font-bold">
          Wait A Minute<span className="animated-dots">...</span>
        </div>
        <style jsx>{`
          @keyframes shake {
            0% { transform: translate(1px, 1px) rotate(0deg); }
            10% { transform: translate(-1px, -2px) rotate(-1deg); }
            20% { transform: translate(-3px, 0px) rotate(1deg); }
            30% { transform: translate(3px, 2px) rotate(0deg); }
            40% { transform: translate(1px, -1px) rotate(1deg); }
            50% { transform: translate(-1px, 2px) rotate(-1deg); }
            60% { transform: translate(-3px, 1px) rotate(0deg); }
            70% { transform: translate(3px, 1px) rotate(-1deg); }
            80% { transform: translate(-1px, -1px) rotate(1deg); }
            90% { transform: translate(1px, 2px) rotate(0deg); }
            100% { transform: translate(1px, -2px) rotate(-1deg); }
          }

          .animate-shake {
            animation: shake 0.5s infinite;
          }

          @keyframes dots {
            0%, 20% { content: "."; }
            40% { content: ".."; }
            60% { content: "..."; }
            80%, 100% { content: "...."; }
          }

          .animated-dots::after {
            content: ".";
            animation: dots 1s infinite steps(4);
          }
        `}</style>
      </div>
    );
  }

  if (!castData) {
    return <div>Cast information not found.</div>;
  }

  const {
    name,
    biography,
    birthday,
    place_of_birth: placeOfBirth,
    profile_path: profilePath,
  } = castData;

  const formattedBiography = biography ? biography.substring(0, 160) : "Biography not available.";

  return (
    <>
      <Head>
        <title>{`${name} - Cast Details | Delgor`}</title>
        <meta name="description" content={formattedBiography} />
        <link rel="canonical" href={`https://www.delgor.com/cast?id=${id}`} />
        <meta property="og:title" content={`${name} - Cast Details | Delgor`} />
        <meta property="og:description" content={formattedBiography} />
        <meta property="og:type" content="profile" />
        <meta property="og:url" content={`https://www.delgor.com/cast?id=${id}`} />
        <meta property="og:image" content={profilePath ? `https://image.tmdb.org/t/p/w500${profilePath}` : '/images/fallback-cast.png'} />
        <meta property="og:image:alt" content={`${name} Profile Picture`} />
        <meta property="og:site_name" content="Delgor" />
        {/* Structured Data for Person */}
        <script type="application/ld+json">
          {JSON.stringify({
            "@context": "https://schema.org",
            "@type": "Person",
            "name": name,
            "description": biography || "Biography not available.",
            "birthDate": birthday || "N/A",
            "birthPlace": placeOfBirth || "N/A",
            "image": profilePath ? `https://image.tmdb.org/t/p/w500${profilePath}` : '/images/fallback-cast.png',
            "url": `https://www.delgor.com/cast?id=${id}`,
          })}
        </script>
      </Head>
      <div className="container mx-auto p-4">
        <CastBasicInfo
          profileImage={`https://image.tmdb.org/t/p/w500${castData.profile_path}`}
          name={castData.name}
          rating={castData.popularity}
          dateOfBirth={castData.birthday || 'N/A'}
          placeOfBirth={castData.place_of_birth || 'N/A'}
          biography={castData.biography || 'Biography not available.'}
        />
        {id && <CastMovies actorId={id} />} {/* Conditionally render CastMovies */}
        {/* AdSense Ad after CastMovies Slider */}
        <div className="w-full my-8">
          <AdSense />
        </div>
      </div>
    </>
  );
};

export default function CastPageWrapper() {
  return (
    <Suspense fallback={<div>Loading...</div>}>
      <CastPage />
    </Suspense>
  );
}
